package demo;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ICoolBarManager;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.rap.rwt.RWT;
import org.eclipse.swt.SWT;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;

import demo.editor.DemoEditorInput;

/**
 * Creates, adds and disposes actions for the menus and action bars of
 * each workbench window.
 */
public class DemoActionBarAdvisor extends ActionBarAdvisor {

	private Action	newEditorAction;

	/**
	 * @param configurer
	 */
	public DemoActionBarAdvisor(IActionBarConfigurer configurer) {
		super(configurer);
		RWT.getUISession().setAttribute(DemoActionBarAdvisor.class.getName(), this);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.ActionBarAdvisor#fillCoolBar(org.eclipse.jface.action.ICoolBarManager)
	 */
	@Override
	protected void fillCoolBar(ICoolBarManager coolBar) {
		IToolBarManager toolbar = new ToolBarManager(SWT.FLAT);
		coolBar.add(toolbar);
		toolbar.add(this.newEditorAction);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.ActionBarAdvisor#fillMenuBar(org.eclipse.jface.action.IMenuManager)
	 */
	@Override
	protected void fillMenuBar(IMenuManager menuBar) {
		MenuManager actionMenu = new MenuManager("Action", "Action");
		menuBar.add(actionMenu);
		actionMenu.add(this.newEditorAction);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.ActionBarAdvisor#makeActions(org.eclipse.ui.IWorkbenchWindow)
	 */
	@Override
	protected void makeActions(IWorkbenchWindow window) {
		this.newEditorAction = new Action() {
			private static final long	serialVersionUID	= -4035033079494462380L;

			@Override
			public void run() {
				try {
					PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().openEditor(new DemoEditorInput(), "demo.editor", true);
				} catch (PartInitException e) {
					e.printStackTrace();
				}
			}
		};
		this.newEditorAction.setId(RWT.getUISession().getId());
		this.newEditorAction.setText("New editor");
		this.register(this.newEditorAction);
	}

}