package demo;

import org.eclipse.rap.rwt.RWT;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;

import demo.editor.DemoEditor;

/**
 * Configures the initial size and appearance of a workbench window.
 */
public class DemoWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor {

	/**
	 * @param configurer
	 */
	public DemoWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
		super(configurer);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#createActionBarAdvisor(org.eclipse.ui.application.IActionBarConfigurer)
	 */
	@Override
	public ActionBarAdvisor createActionBarAdvisor(IActionBarConfigurer configurer) {
		return new DemoActionBarAdvisor(configurer);
	}

	/**
	 * {@link WorkbenchWindowAdvisor#postWindowCreate()}
	 */
	@Override
	public void postWindowCreate() {
		Shell shell = this.getWindowConfigurer().getWindow().getShell();
		shell.setMaximized(true);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#postWindowOpen()
	 */
	@Override
	public void postWindowOpen() {
		super.postWindowOpen();
		// override browser default shortcut keys and invoke customize event handling.
		String[] allowedKeyStrs = new String[] { "ENTER", "BREAK", "PAGE_DOWN", "PAGE_UP", "F1", "F2", "F3", "F4", "F5", "F6", "F7", "F8", "F9", "F10", "F11",
				"F12", "SHIFT+F1", "SHIFT+F2", "SHIFT+F3", "SHIFT+F4", "SHIFT+F5", "SHIFT+F6", "SHIFT+F7", "SHIFT+F8", "SHIFT+F9", "SHIFT+F10", "SHIFT+F11",
				"SHIFT+F12" }; 
		Display.getCurrent().setData(RWT.CANCEL_KEYS, allowedKeyStrs);
		Display.getCurrent().setData(RWT.ACTIVE_KEYS, allowedKeyStrs);
		Display.getCurrent().addFilter(SWT.KeyUp, new Listener() {
			private static final long	serialVersionUID	= -8151749348752499546L;

			@Override
			public void handleEvent(Event event) {
				IEditorPart editPart = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().getActiveEditor();
				if ((editPart != null) && (editPart instanceof DemoEditor)) {
					((DemoEditor) editPart).keyPress(event);
				}
			}
		});
	}

	/**
	 * {@link WorkbenchWindowAdvisor#preWindowOpen}
	 */
	@Override
	public void preWindowOpen() {
		IWorkbenchWindowConfigurer configurer = this.getWindowConfigurer();
		configurer.setTitle("Demo");
		configurer.setShowMenuBar(true);
		configurer.setShowCoolBar(true);
		configurer.setShowPerspectiveBar(false);
		configurer.setShowStatusLine(false);
		configurer.setShellStyle(SWT.NO_TRIM | SWT.NO_FOCUS);
	}
}