/*******************************************************************************
 * Copyright (c) 2002, 2012 Innoopract Informationssysteme GmbH and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Innoopract Informationssysteme GmbH - initial API and implementation
 *    EclipseSource - ongoing development
 ******************************************************************************/
package demo.editor;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.part.EditorPart;

public class DemoEditor extends EditorPart {

	/**
	 * Back end thread to run some business logic and then update front end widget
	 */
	private class ListenerThread implements Runnable {

		public Object	lock	= new Object();
		private boolean	quit	= false;

		@Override
		public void run() {
			try {
				while (!this.quit) {
					synchronized (this.lock) {
						try {
							this.lock.wait();
						} catch (InterruptedException e) {
						}
						this.quit = this.quit || DemoEditor.this.parent.getDisplay().isDisposed();
						if (!this.quit) {
							DemoEditor.this.parent.getDisplay().asyncExec(new Runnable() {
								@Override
								public void run() {
									synchronized (ListenerThread.this.lock) {
										if (!DemoEditor.this.newText.trim().isEmpty()) {
											System.out.println("new Text: " + DemoEditor.this.newText);
											String oldText = "";
											if (DemoEditor.this.text != null) {
												oldText = DemoEditor.this.text.getText();
												DemoEditor.this.text.dispose();
												DemoEditor.this.text = null;
											}
											DemoEditor.this.text = new Text(DemoEditor.this.parent, SWT.WRAP);
											DemoEditor.this.text.setText(oldText + (oldText.isEmpty() ? "" : "\n") + DemoEditor.this.newText);
											DemoEditor.this.text.setEditable(false);
											DemoEditor.this.text.setLocation(DemoEditor.this.parent.getBounds().x, DemoEditor.this.parent.getBounds().y);
											DemoEditor.this.text.setSize(DemoEditor.this.text.computeSize(SWT.DEFAULT, SWT.DEFAULT));
											DemoEditor.this.text.setVisible(true);
											DemoEditor.this.text.setFocus();
										}
										DemoEditor.this.newText = "";
										ListenerThread.this.lock.notifyAll();
									}
									//									parent.setRedraw(true);
								}
							});
						}
					}
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
			System.out.println("quit.");
		}
	}

	private String			newText	= "";
	private Composite		parent	= null;
	private Text			text	= null;
	private ListenerThread	thread	= new ListenerThread();

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	public void createPartControl(final Composite parent) {
		this.parent = parent;
		parent.setLayout(new FillLayout());
		(new Thread(this.thread)).start();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#dispose()
	 */
	@Override
	public void dispose() {
		synchronized (this.thread.lock) {
			this.thread.quit = true;
			this.thread.lock.notifyAll();
		}
		super.dispose();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.EditorPart#doSave(org.eclipse.core.runtime.IProgressMonitor)
	 */
	@Override
	public void doSave(final IProgressMonitor monitor) {
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.EditorPart#doSaveAs()
	 */
	@Override
	public void doSaveAs() {
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.EditorPart#init(org.eclipse.ui.IEditorSite, org.eclipse.ui.IEditorInput)
	 */
	@Override
	public void init(final IEditorSite site, final IEditorInput input) throws PartInitException {
		this.setSite(site);
		this.setInput(input);
		this.setPartName(input.getName());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.EditorPart#isDirty()
	 */
	@Override
	public boolean isDirty() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.EditorPart#isSaveAsAllowed()
	 */
	@Override
	public boolean isSaveAsAllowed() {
		return false;
	}

	/**
	 * accept key strike from browser and then wake back end thread.
	 * @param event
	 */
	public synchronized void keyPress(final Event event) {
		Display.getCurrent().asyncExec(new Runnable() {
			@Override
			public void run() {
				synchronized (DemoEditor.this.thread.lock) {
					if (DemoEditor.this.newText.trim().isEmpty()) {
						DemoEditor.this.newText = System.currentTimeMillis() + " - key: " + event.keyCode;
					}
					DemoEditor.this.thread.lock.notify();
					DemoEditor.this.setFocus();
				}
			}
		});
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#setFocus()
	 */
	@Override
	public void setFocus() {
		if (this.text != null) {
			this.text.setFocus();
		}
	}
}
